@@ -2,12 +2,10 @@ from typing import Any, Dict, Tuple, List, DefaultDict, Optional
 from collections import defaultdict
 from urllib.parse import urlparse
 
-import httpx
 from retrying import retry  # type: ignore
 
 from capella_console_client.logconf import logger
 from capella_console_client.session import CapellaConsoleSession
-from capella_console_client.exceptions import AuthorizationError
 from capella_console_client.config import (
     ALL_SUPPORTED_FIELDS,
     ALL_SUPPORTED_SORTBY,
@@ -17,8 +15,6 @@ from capella_console_client.config import (
     OPERATOR_SUFFIXES,
     DEFAULT_PAGE_SIZE,
     DEFAULT_MAX_FEATURE_COUNT,
-    API_GATEWAY,
-    CONSOLE_API_URL,
 )
 from capella_console_client.hooks import retry_if_http_status_error
 
@@ -141,7 +137,9 @@ def _paginated_search(
 def _get_next_page_href(page_data: Dict[str, Any]) -> Optional[str]:
     links = page_data.get("links", [])
     try:
-        next_href = next(filter(lambda c: c["rel"] == "next", links))["href"]
+        next_href: Optional[str] = next(filter(lambda c: c["rel"] == "next", links))[
+            "href"
+        ]
     except StopIteration:
         next_href = None
 
@@ -162,14 +160,15 @@ def _page_search(
 ) -> Dict[str, Any]:
 
     if next_href:
-        # TODO: STAC api to return normalized asset hrefs, not <API_GATEWAY>...
-        if urlparse(next_href).netloc != urlparse(session.search_url).netloc:
-            next_href = next_href.replace(API_GATEWAY, f"{CONSOLE_API_URL}/catalog")
+        # STAC API to return normalized asset hrefs, not api gateway - fixing this here ...
+        url_parsed = urlparse(next_href)
+        if url_parsed.netloc != urlparse(session.search_url).netloc:
+            next_href = f"{session.search_url}?{url_parsed.query}"
 
     url = session.search_url if next_href is None else next_href
 
     with session:
         resp = session.post(url, json=payload)
 
-    data = resp.json()
+    data: Dict[str, Any] = resp.json()
     return data
